<div class="table-responsive">
    <table class='table' id='council-members'>
        <thead>
            <tr>
                <th></th>
                <th>
                    {{ CITY_VOCAB.COUNCIL_MEMBER }}
                </th>
                <th>
                    {{CITY_VOCAB.MUNICIPAL_DISTRICT}}
                </th>
            </tr>
        </thead>
        <tbody>
            {% for post in posts %}
                <tr id="polygon-{{post.label | slugify}}">
                    <td>
                        {% if post.current_member %}
                            <div class="thumbnail-square">
                                <img src='{{post.current_member.person.headshot_url}}' alt='{{post.current_member.person.name}}' title='{{post.current_member.person.name}}' class='img-responsive img-thumbnail' />
                            </div>
                        {% endif %}
                    </td>
                    <td>
                        {% if post.current_member %}
                            {{ post.current_member.person.link_html | safe }}
                            {% if post.current_member.person.is_speaker %}
                                <br /><span class='label label-default'>Council Speaker</span>
                                <span class='label label-success'><i class='fa fa-fw fa-check-square-o'></i> Verified</span>
                            {% endif %}
                        {% else %}
                            Vacant
                        {% endif %}
                    </td>
                    <td>{{post.label}}</td>
                </tr>
            {% endfor %}
        </tbody>
    </table>
</div>